-- Sistemas Integrados TEKNISA
-- HRM - Controle de frequncia
--
-- Nome: 0000_FUNTEKO_PONTO_TO_HRM.sql
--
-- Descrio:
-- Gera comandos de insero de dados na estrutura do "HRM - Controle de Frequncia", tendo como
-- fonte de dados o ponto manual lanado atravs da rotina de apurao de jornada da Intranet.
--
-- Parmetros:
-- P_NRORG - Nmero da organizao
-- P_CDEMPRESA - Cdigo da empresa
-- P_CDFUNC - Cdigo do funcionrio
-- P_DTINICIAL - Data inicial do perodo a ser considerado
-- P_DTFINAL - Data final do perodo a ser considerado
-- P_DTCOMPETENCIA - Data de competncia
-- P_NRORG_PADRAO - Nmero da organizao padro (opcional - default 0)
-- P_NRCOLETOR_REP - Nmero do coletor considerado para lanamento das marcaes (opcional - default 18) 
-- P_NRCOLETOR_DIG - Nmero do coletor considerado para lanamentos manuais de marcaes (opcional - default 24) 
--	
-- Exemplo de utilizao
-- SELECT * 
--   FROM TABLE (PONTO_TO_HRM (:P_NRORG, :P_CDEMPRESA, :P_CDFUNC, :P_DTINICIAL, :P_DTFINAL, :P_DTCOMPETENCIA))
--
-- Criao:
-- 24/04/2015 Newton Neves dos Santos

BEGIN
	EXECUTE IMMEDIATE 'SELECT USR_NRORG_SAAS FROM FUNCIONARIO WHERE ROWNUM = 1'; 
EXCEPTION
	WHEN OTHERS THEN
		EXECUTE IMMEDIATE 'ALTER TABLE FUNCIONARIO ADD USR_NRORG_SAAS NUMBER';
END;
/  

BEGIN
	EXECUTE IMMEDIATE 'SELECT USR_NRVINCULO_SAAS FROM FUNCIONARIO WHERE ROWNUM = 1'; 
EXCEPTION
	WHEN OTHERS THEN
		EXECUTE IMMEDIATE 'ALTER TABLE FUNCIONARIO ADD USR_NRVINCULO_SAAS NUMBER';
END;
/

DROP FUNCTION PONTO_TO_HRM
/
DROP TYPE PONTO_TO_HRM_TABLE
/
DROP TYPE PONTO_TO_HRM_TYPE
/

CREATE TYPE PONTO_TO_HRM_TYPE AS OBJECT 
   (DSCOMANDOSQL VARCHAR2(4000))
/

CREATE TYPE PONTO_TO_HRM_TABLE AS TABLE OF PONTO_TO_HRM_TYPE
/

CREATE OR REPLACE FUNCTION PONTO_TO_HRM
  (P_NRORG IN FPA_PONTO.NRORG%TYPE,
   P_CDEMPRESA IN FPA_PONTO.CDEMPRESA%TYPE,
   P_CDFUNC IN VARCHAR2,
   P_DTINICIAL IN FPA_PONTO.DTPONTO%TYPE,
   P_DTFINAL IN FPA_PONTO.DTPONTO%TYPE, 
	P_DTCOMPETENCIA IN FPA_PONTO.DTPONTO%TYPE, 
	P_NRORG_PADRAO IN FPA_PONTO.NRORG%TYPE DEFAULT 0,
   P_NRCOLETOR_REP IN NUMBER DEFAULT NULL, 
	P_NRCOLETOR_DIG IN NUMBER DEFAULT NULL,
	P_CTRL_JORNADA IN VARCHAR2 DEFAULT 'S') 
RETURN PONTO_TO_HRM_TABLE PIPELINED 
IS
   OUT_RECORD PONTO_TO_HRM_TYPE := PONTO_TO_HRM_TYPE (NULL);
   V_CDEMPRESA FPA_PONTO.CDEMPRESA%TYPE;
	V_CDFUNC FPA_PONTO.CDFUNC%TYPE;
	V_DTPONTO FPA_PONTO.DTPONTO%TYPE;
	V_STDTPONTO VARCHAR2(10);
	V_DTHRMARCACAO FPA_PONTO.DTENTRADA%TYPE;
	V_IDPONTO FPA_PONTO.IDPONTO%TYPE;
	V_IDAUTDEBBANCOHORAS FPA_PONTO.IDAUTDEBBANCOHORAS%TYPE;
	V_HRREMUNERADA FPA_PONTO.HRREMUNERADA%TYPE;
	V_IDORIGEM VARCHAR2(10);
	V_ID_ANT_INT_DEP VARCHAR2(01);
	V_IDSENTIDO VARCHAR2(01);
	V_IDALMOCO FPA_AUSENCIAPONTO.IDAUSENCIAALMOCO%TYPE;
	V_IDABONO FPA_AUSENCIAPONTO.IDAUSENCIAABONADA%TYPE;
	V_DSJUSTIFICATIVA FPA_AUSENCIAPONTO.DSOBSERVACAOAUSENCIA%TYPE;
	V_NRORG_SAAS FUNCIONARIO.USR_NRORG_SAAS%TYPE;
	V_NRVINCULOM_SAAS FUNCIONARIO.USR_NRVINCULO_SAAS%TYPE;
	V_NMMOTIVOEXCEFREQ GPE_MOTIVOEXCEFREQ.NMMOTIVOEXCEFREQ%TYPE;
	V_DSCOMANDOSQL	VARCHAR2(4000);
	V_NRORG FPA_PONTO.NRORG%TYPE;
	V_NRMARCACAOPONTO NUMBER;
	V_NRVINCULOM NUMBER;
	V_DTHRMARCACAOPONTO FPA_PONTO.DTPONTO%TYPE;
	V_DTHRAJUSTADA FPA_PONTO.DTPONTO%TYPE;
	V_IDDIAOCORRENCIA VARCHAR2(02);
	V_DSJUSTIF_MARCACAO VARCHAR2(100);
	V_DSJUSTIF_OCORRENCIA VARCHAR2(100);
	V_NRCOLETOR NUMBER;
	V_DTINICIOPROGOCOR VARCHAR2(10);
	V_DTFIMPROGOCOR VARCHAR2(10);
	V_DTCOMPETENCIA VARCHAR2(10);
	V_NRCOLETOR_REP NUMBER;
	V_NRCOLETOR_DIG NUMBER;
	V_COUNT_SQL NUMBER;
	
   CURSOR C_MARC_PONTO IS 
		SELECT CDEMPRESA, CDFUNC, DTPONTO, DTHRMARCACAO, IDPONTO, IDAUTDEBBANCOHORAS, 
				 IDORIGEM, ID_ANT_INT_DEP, IDSENTIDO, IDALMOCO, IDABONO, DSJUSTIFICATIVA,
				 NRORG, NRVINCULO, NMMOTIVOEXCEFREQ, HRREMUNERADA
		  FROM (SELECT P.CDEMPRESA, P.CDFUNC, P.DTPONTO, P.DTENTRADA AS DTHRMARCACAO,
							P.IDPONTO,
							P.IDAUTDEBBANCOHORAS,
							'CATRACA' AS IDORIGEM,
							'1' AS ID_ANT_INT_DEP, 
							'E' AS IDSENTIDO, 
							NULL AS IDALMOCO, 
							NULL AS IDABONO, 
							NULL AS DSJUSTIFICATIVA,
							F.USR_NRORG_SAAS AS NRORG,
							F.USR_NRVINCULO_SAAS AS NRVINCULO,
							M.NMMOTIVOEXCEFREQ,
                     P.HRREMUNERADA
					 FROM FPA_PONTO P, FUNCIONARIO F, GPE_MOTIVOEXCEFREQ M
					WHERE P.NRORG = P_NRORG
					  AND P.CDEMPRESA = P_CDEMPRESA
					  AND (P_CDFUNC = 'T' OR INSTR(P_CDFUNC, '_'||P.CDFUNC||'_') > 0)
					  AND P.DTPONTO BETWEEN P_DTINICIAL AND P_DTFINAL
					  AND F.CDEMPRESA = P.CDEMPRESA
					  AND F.CDFUNC = P.CDFUNC
					  AND P.NRMOTIVOEXCEFREQ = M.NRMOTIVOEXCEFREQ(+)
					UNION ALL
				  SELECT P.CDEMPRESA, P.CDFUNC, P.DTPONTO, P.DTSAIDA, 
							P.IDPONTO,
							NULL AS IDAUTDEBBANCOHORAS,
							'CATRACA' AS IDORIGEM,
							'1' AS ID_ANT_INT_DEP, 
							'S' AS IDSENTIDO, 
							NULL AS IDALMOCO, 
							NULL AS IDABONO, 
							NULL AS DSJUSTIFICATIVA,
							F.USR_NRORG_SAAS AS NRORG,
							F.USR_NRVINCULO_SAAS AS NRVINCULO,
							NULL AS NMMOTIVOEXCEFREQ,
							NULL AS HRREMUNERADA
					 FROM FPA_PONTO P, FUNCIONARIO F
					WHERE P.NRORG = P_NRORG
					  AND P.CDEMPRESA = P_CDEMPRESA
					  AND (P_CDFUNC = 'T' OR INSTR(P_CDFUNC, '_'||P.CDFUNC||'_') > 0)
					  AND P.DTPONTO BETWEEN P_DTINICIAL AND P_DTFINAL
					  AND P.IDPONTO = 'ATIVIDADE_INTERNA'
					  AND F.CDEMPRESA = P.CDEMPRESA
					  AND F.CDFUNC = P.CDFUNC
					UNION ALL
				  SELECT P.CDEMPRESA, P.CDFUNC, P.DTPONTO, A.DTINICIOAUSENCIA, 
							P.IDPONTO,
							NULL AS IDAUTDEBBANCOHORAS,
							CASE WHEN A.DTINICIOAUSENCIA <= P.DTENTRADA OR A.DTINICIOAUSENCIA >= P.DTSAIDA THEN 'MANUAL' ELSE 'CATRACA' END AS IDORIGEM,
							CASE WHEN A.DTINICIOAUSENCIA <= P.DTENTRADA THEN '0' WHEN A.DTINICIOAUSENCIA >= P.DTSAIDA THEN '2' ELSE '1' END AS ID_ANT_INT_DEP, 
							'S' AS IDSENTIDO, 
							A.IDAUSENCIAALMOCO AS IDALMOCO, 
							A.IDAUSENCIAABONADA AS IDABONO, 
							A.DSOBSERVACAOAUSENCIA AS DSJUSTIFICATIVA,
							F.USR_NRORG_SAAS AS NRORG,
							F.USR_NRVINCULO_SAAS AS NRVINCULO,
							NULL AS NMMOTIVOEXCEFREQ,
							NULL AS HRREMUNERADA
					 FROM FPA_PONTO P, FPA_AUSENCIAPONTO A, FUNCIONARIO F
					WHERE P.NRORG = P_NRORG
					  AND P.CDEMPRESA = P_CDEMPRESA
					  AND (P_CDFUNC = 'T' OR INSTR(P_CDFUNC, '_'||P.CDFUNC||'_') > 0)
					  AND P.DTPONTO BETWEEN P_DTINICIAL AND P_DTFINAL
					  AND P.IDPONTO = 'ATIVIDADE_INTERNA'
					  AND A.NRORG = P.NRORG
					  AND A.CDEMPRESA = P.CDEMPRESA
					  AND A.CDFUNC = P.CDFUNC
					  AND A.DTPONTO = P.DTPONTO
					  AND F.CDEMPRESA = P.CDEMPRESA
					  AND F.CDFUNC = P.CDFUNC
					UNION ALL
				  SELECT P.CDEMPRESA, P.CDFUNC, P.DTPONTO, A.DTFIMAUSENCIA, 
							P.IDPONTO,
							NULL AS IDAUTDEBBANCOHORAS,
							CASE WHEN A.DTFIMAUSENCIA <= P.DTENTRADA OR A.DTFIMAUSENCIA >= P.DTSAIDA THEN 'MANUAL' ELSE 'CATRACA' END AS IDORIGEM,
							CASE WHEN A.DTFIMAUSENCIA <= P.DTENTRADA THEN '0' WHEN A.DTFIMAUSENCIA >= P.DTSAIDA THEN '2' ELSE '1' END AS ID_ANT_INT_DEP, 
							'E' AS IDSENTIDO, 
							CASE WHEN A.DTFIMAUSENCIA <= P.DTENTRADA OR A.DTFIMAUSENCIA >= P.DTSAIDA THEN A.IDAUSENCIAALMOCO ELSE NULL END AS IDALMOCO, 
							CASE WHEN A.DTFIMAUSENCIA <= P.DTENTRADA OR A.DTFIMAUSENCIA >= P.DTSAIDA THEN A.IDAUSENCIAABONADA ELSE NULL END AS IDABONO, 
							CASE WHEN A.DTFIMAUSENCIA <= P.DTENTRADA OR A.DTFIMAUSENCIA >= P.DTSAIDA THEN A.DSOBSERVACAOAUSENCIA ELSE NULL END AS DSJUSTIFICATIVA,
							F.USR_NRORG_SAAS AS NRORG,
							F.USR_NRVINCULO_SAAS AS NRVINCULO,
							NULL AS NMMOTIVOEXCEFREQ,
							NULL AS HRREMUNERADA
					 FROM FPA_PONTO P, FPA_AUSENCIAPONTO A, FUNCIONARIO F
					WHERE P.NRORG = P_NRORG
					  AND P.CDEMPRESA = P_CDEMPRESA
					  AND (P_CDFUNC = 'T' OR INSTR(P_CDFUNC, '_'||P.CDFUNC||'_') > 0)
					  AND P.DTPONTO BETWEEN P_DTINICIAL AND P_DTFINAL
					  AND P.IDPONTO = 'ATIVIDADE_INTERNA'
					  AND A.NRORG = P.NRORG
					  AND A.CDEMPRESA = P.CDEMPRESA
					  AND A.CDFUNC = P.CDFUNC
					  AND A.DTPONTO = P.DTPONTO
					  AND F.CDEMPRESA = P.CDEMPRESA
					  AND F.CDFUNC = P.CDFUNC) P
		 ORDER BY CDEMPRESA, CDFUNC, DTPONTO, DTHRMARCACAO, ID_ANT_INT_DEP, IDSENTIDO;
		 
   CURSOR C_SERV_PREST IS 
		SELECT S.CDEMPRESA, S.CDFUNC, S.DTSERVPREST, S.IDSERVPREST,
				 F.USR_NRORG_SAAS AS NRORG, 
				 F.USR_NRVINCULO_SAAS AS NRVINCULO
		  FROM SERVPREST S, FUNCIONARIO F
		 WHERE S.NRORG = P_NRORG
			AND S.CDEMPRESA = P_CDEMPRESA
			AND (P_CDFUNC = 'T' OR INSTR(P_CDFUNC, '_'||S.CDFUNC||'_') > 0)
			AND S.DTSERVPREST BETWEEN P_DTINICIAL AND P_DTFINAL
			AND S.IDSERVPREST = 'FALTA_NAO_JUSTIFICADA'
			AND F.NRORG = S.NRORG
			AND F.CDEMPRESA = S.CDEMPRESA
			AND F.CDFUNC = S.CDFUNC;
	 
BEGIN
   /* ######################################### */
   /* INICIO - Atribuio de valores constantes */
   /* ------ */
	V_NRCOLETOR_REP := NVL(P_NRCOLETOR_REP, 18); 
	V_NRCOLETOR_DIG := NVL(P_NRCOLETOR_DIG, 24);   
	V_COUNT_SQL := 1;
   /* --- */
   /* FIM - Atribuio de valores constantes */
   /* ###################################### */

	IF P_CTRL_JORNADA = 'S' THEN
		OPEN C_MARC_PONTO;
		LOOP
			FETCH C_MARC_PONTO INTO V_CDEMPRESA, V_CDFUNC, V_DTPONTO, V_DTHRMARCACAO, V_IDPONTO, V_IDAUTDEBBANCOHORAS, 
											V_IDORIGEM, V_ID_ANT_INT_DEP, V_IDSENTIDO, V_IDALMOCO, V_IDABONO, V_DSJUSTIFICATIVA,
											V_NRORG_SAAS, V_NRVINCULOM_SAAS, V_NMMOTIVOEXCEFREQ, V_HRREMUNERADA;
			EXIT WHEN C_MARC_PONTO%NOTFOUND;
			
			V_NRORG := NVL(V_NRORG_SAAS, V_NRORG);
			V_NRVINCULOM := NVL(V_NRVINCULOM_SAAS, V_NRVINCULOM);
			V_DTHRMARCACAOPONTO := TO_CHAR(V_DTHRMARCACAO, 'DD/MM/YYYY HH24:MI:SS');
			V_DTHRAJUSTADA := TO_CHAR(V_DTHRMARCACAO, 'DD/MM/YYYY HH24:MI:SS');
			V_IDDIAOCORRENCIA := CASE WHEN TRUNC(V_DTHRMARCACAO) > V_DTPONTO THEN 'DA' WHEN TRUNC(V_DTHRMARCACAO) < V_DTPONTO THEN 'DS' ELSE 'DC' END;
			V_DSJUSTIF_MARCACAO := SUBSTR(V_DSJUSTIFICATIVA, 1, 100);
			V_NRCOLETOR := CASE WHEN V_IDORIGEM = 'CATRACA' THEN V_NRCOLETOR_REP ELSE V_NRCOLETOR_DIG END;
			V_STDTPONTO := TO_CHAR(V_DTPONTO, 'DD/MM/YYYY');
			V_DTINICIOPROGOCOR := V_STDTPONTO;
			V_DTFIMPROGOCOR := V_STDTPONTO;
			V_DTCOMPETENCIA := TO_CHAR(P_DTCOMPETENCIA, 'DD/MM/YYYY');
			
			V_DSCOMANDOSQL := '';
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'DECLARE'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_NRMARCACAOPONTO NUMBER;'||CHR(10);
			
			IF (V_IDALMOCO = 'S') OR 
				(V_IDAUTDEBBANCOHORAS = 'S') OR
				(V_IDABONO = 'S' AND V_IDORIGEM = 'CATRACA') OR 
				(V_IDPONTO IN ('FALTA_ABONADA', 'FALTA_COMPENSADA', 'AFASTAMENTO_INSS', 'FERIAS', 'ATIVIDADE_EXTERNA')) THEN 
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_NRPROGOCORRENCIA NUMBER;'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_NRTIPOPROGOCORRENCIA NUMBER;'||CHR(10);		
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_NRHORDIAM NUMBER;'||CHR(10);		
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_IDTIPOHORARIO GPE_HORDIAH.IDTIPOHORARIO%TYPE;'||CHR(10);		
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_NRINTERVALOHORARIO NUMBER;'||CHR(10);		
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_QTMAXIMAPROGOCOR PTO_PROGOCORRENCIA.QTMAXIMAPROGOCOR%TYPE;'||CHR(10);		
			END IF;	
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_STNOVOCOD NOVOCODIGO.NRSEQUENCIAL%TYPE;'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_ERR_NUM NUMBER;'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_ERR_MSG VARCHAR2(100);'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'BEGIN'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    dbms_output.put_line(''Comando no.: '||TO_CHAR(V_COUNT_SQL)||''');'||CHR(10);
			IF V_IDPONTO = 'ATIVIDADE_INTERNA' THEN 
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		NOVO_CODIGO(''GPE_MARCACAOPONTO'', V_STNOVOCOD, 1, '||V_NRORG||');'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_NRMARCACAOPONTO := TO_NUMBER(V_STNOVOCOD);'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		INSERT INTO GPE_MARCACAOPONTO (NRORG, NRMARCACAOPONTO, NRVINCULOM, DTHRMARCACAOPONTO, '||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'												 DTHRAJUSTADA, IDDIAOCORRENCIA, DSJUSTIFICATIVA, NRCOLETOR)'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			  VALUES ('||V_NRORG||', V_NRMARCACAOPONTO, '||V_NRVINCULOM||', TO_DATE('''||V_DTHRMARCACAOPONTO||''', ''DD/MM/YYYY HH24:MI:SS''),'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'						 TO_DATE('''||V_DTHRAJUSTADA||''', ''DD/MM/YYYY HH24:MI:SS''), '''||V_IDDIAOCORRENCIA||''', '''||V_DSJUSTIF_MARCACAO||''', '||V_NRCOLETOR||');'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		COMMIT;'||CHR(10);
			END IF;	
			IF (V_IDALMOCO = 'S') OR 
				(V_IDAUTDEBBANCOHORAS = 'S') OR
				(V_IDABONO = 'S' AND V_IDORIGEM = 'CATRACA') OR 
				(V_IDPONTO IN ('FALTA_ABONADA', 'FALTA_COMPENSADA', 'AFASTAMENTO_INSS', 'FERIAS', 'ATIVIDADE_EXTERNA')) THEN 
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		NOVO_CODIGO(''PTO_PROGOCORRENCIA'', V_STNOVOCOD, 1, '||V_NRORG||');'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_NRPROGOCORRENCIA := TO_NUMBER(V_STNOVOCOD);'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		SELECT HT.NRHORDIAM, HD.IDTIPOHORARIO, IH.NRINTERVALOHORARIO'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  INTO V_NRHORDIAM, V_IDTIPOHORARIO, V_NRINTERVALOHORARIO'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  FROM (SELECT NRORG, MAX(NRTURNO) NRTURNO'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					 FROM GPE_ALTEESCALA'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					WHERE NRORG = '||V_NRORG||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					  AND NRVINCULOM = '||V_NRVINCULOM||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					  AND TO_DATE('''||V_DTCOMPETENCIA||''',''DD/MM/YYYY'') BETWEEN DTINIESCALA AND NVL(DTFIMESCALA, TO_DATE('''||V_STDTPONTO||''', ''DD/MM/YYYY''))'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					GROUP BY NRORG) AE,'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'				 (SELECT NRORG, NRTURNO, TO_DATE('''||V_STDTPONTO||''',''DD/MM/YYYY'')-DTDATABASE AS NRDIASENTRE'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					 FROM GPE_TURNO'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					WHERE NRORG = '||V_NRORG||') TU,'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'				 (SELECT NRORG, NRTURNO, NRHORDIAM,'||CHR(10); 
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'							ROW_NUMBER() OVER (PARTITION BY NRORG, NRTURNO ORDER BY NRSEQHORARIO) AS NRSEQHR'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					 FROM GPE_HORARIOTURNO'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					WHERE NRORG = '||V_NRORG||CHR(10); 
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					ORDER BY NRORG, NRTURNO, NRSEQHORARIO) HT,'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'				 (SELECT NRORG, NRTURNO, COUNT(*) AS QTHORARIOS'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					 FROM GPE_HORARIOTURNO'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					WHERE NRORG = '||V_NRORG||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					GROUP BY NRORG, NRTURNO) QH,'||CHR(10); 
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'				 (SELECT NRORG, NRHORDIAM, MAX(DTMESCOMPETENC) AS DTMESCOMPETENC'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					 FROM GPE_HORDIAH'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					WHERE NRORG = '||V_NRORG||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					  AND DTMESCOMPETENC <= TO_DATE('''||V_DTCOMPETENCIA||''', ''DD/MM/YYYY'')'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					GROUP BY NRORG, NRHORDIAM) HH,'||CHR(10); 
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'				 (SELECT NRORG, NRHORDIAM, MIN(NRSEQINTERVHORARIO) NRSEQINTERVHORARIO'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					 FROM GPE_INTERVALOSHORARIO'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					WHERE NRORG = '||V_NRORG||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'					GROUP BY NRORG, NRHORDIAM) IV, GPE_INTERVALOSHORARIO IH, GPE_HORDIAH HD'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		 WHERE AE.NRORG = TU.NRORG'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND AE.NRTURNO = TU.NRTURNO'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND AE.NRORG = HT.NRORG'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND AE.NRTURNO = HT.NRTURNO'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND HT.NRORG = HH.NRORG'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND HT.NRHORDIAM = HH.NRHORDIAM'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND HD.NRORG = HH.NRORG'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND HD.NRHORDIAM = HH.NRHORDIAM'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND HD.DTMESCOMPETENC = HH.DTMESCOMPETENC'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND IV.NRORG(+) = HH.NRORG'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND IV.NRHORDIAM(+) = HH.NRHORDIAM'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND IH.NRORG(+) = IV.NRORG'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND IH.NRHORDIAM(+) = IV.NRHORDIAM'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND IH.NRSEQINTERVHORARIO(+) = IV.NRSEQINTERVHORARIO'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND AE.NRORG = QH.NRORG'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND AE.NRTURNO = QH.NRTURNO'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			AND HT.NRSEQHR-1 = MOD(TU.NRDIASENTRE, QH.QTHORARIOS);'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
				IF (V_IDALMOCO = 'S') THEN
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		SELECT NRTIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  INTO V_NRTIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  FROM PTO_TIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		 WHERE NRORG = '||P_NRORG_PADRAO||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		   AND CDTIPOPROGOCORRENCIA = ''IDENTIFICA_INTERVALO'';'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_QTMAXIMAPROGOCOR := NULL;'||CHR(10);
					V_DSJUSTIF_OCORRENCIA := '';
				END IF;	
				IF (V_IDABONO = 'S' AND V_IDORIGEM = 'CATRACA') THEN
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		SELECT NRTIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  INTO V_NRTIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  FROM PTO_TIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		 WHERE NRORG = '||P_NRORG_PADRAO||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		   AND CDTIPOPROGOCORRENCIA = ''SAIDA_AUTORIZADA'';'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_NRHORDIAM := NULL;'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_NRINTERVALOHORARIO := NULL;'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_QTMAXIMAPROGOCOR := NULL;'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
					V_DSJUSTIF_OCORRENCIA := V_DSJUSTIFICATIVA;
				END IF;	
				IF (V_IDPONTO IN ('FALTA_ABONADA', 'AFASTAMENTO_INSS', 'FERIAS')) THEN
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		SELECT NRTIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  INTO V_NRTIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  FROM PTO_TIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		 WHERE NRORG = '||P_NRORG_PADRAO||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		   AND CDTIPOPROGOCORRENCIA = ''FALTA_ABONADA'';'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_NRMARCACAOPONTO := NULL;'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_NRHORDIAM := NULL;'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_NRINTERVALOHORARIO := NULL;'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_QTMAXIMAPROGOCOR := NULL;'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
					IF V_IDPONTO = 'FALTA_ABONADA' THEN
						V_DSJUSTIF_OCORRENCIA := V_NMMOTIVOEXCEFREQ;
					END IF;	
					IF V_IDPONTO = 'AFASTAMENTO_INSS' THEN
						V_DSJUSTIF_OCORRENCIA := V_NMMOTIVOEXCEFREQ;
					END IF;	
					IF V_IDPONTO = 'FERIAS' THEN
						V_DSJUSTIF_OCORRENCIA := 'Frias';
					END IF;	
				END IF;	
				IF (V_IDPONTO = 'FALTA_COMPENSADA' OR V_IDAUTDEBBANCOHORAS = 'S') THEN
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		SELECT NRTIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  INTO V_NRTIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  FROM PTO_TIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		 WHERE NRORG = '||P_NRORG_PADRAO||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		   AND CDTIPOPROGOCORRENCIA = ''AUSENC_COMP_SE_CRED'';'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_NRMARCACAOPONTO := NULL;'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_NRHORDIAM := NULL;'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_NRINTERVALOHORARIO := NULL;'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_QTMAXIMAPROGOCOR := NULL;'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
					V_DSJUSTIF_OCORRENCIA := '';
				END IF;	
				IF (V_IDPONTO = 'ATIVIDADE_EXTERNA') THEN
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		SELECT NRTIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  INTO V_NRTIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  FROM PTO_TIPOPROGOCORRENCIA'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		 WHERE NRORG = '||P_NRORG_PADRAO||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		   AND CDTIPOPROGOCORRENCIA = ''AUSENCIA_EXTRAJORNADA'';'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_NRMARCACAOPONTO := NULL;'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_NRHORDIAM := NULL;'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_NRINTERVALOHORARIO := NULL;'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_QTMAXIMAPROGOCOR := '''||V_HRREMUNERADA||''';'||CHR(10);
					V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
					V_DSJUSTIF_OCORRENCIA := 'Atividade externa';
				END IF;	
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		INSERT INTO PTO_PROGOCORRENCIA(NRORG, NRPROGOCORRENCIA, NRVINCULOM, DTINICIOPROGOCOR, DTFIMPROGOCOR, NRMARCACAOPONTO, QTMAXIMAPROGOCOR,'||CHR(10); 
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		                               IDPROGOCORCONFIRMADA, NRTIPOPROGOCORRENCIA, NRHORDIAM, IDTIPOHORARIO, NRINTERVALOHORARIO, DSOBSERVACAO)'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			  VALUES ('||V_NRORG||', V_NRPROGOCORRENCIA, '||V_NRVINCULOM||', TO_DATE('''||V_DTINICIOPROGOCOR||''', ''DD/MM/YYYY''), TO_DATE('''||V_DTFIMPROGOCOR||''', ''DD/MM/YYYY''), V_NRMARCACAOPONTO, V_QTMAXIMAPROGOCOR,'||CHR(10); 
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		             ''S'', V_NRTIPOPROGOCORRENCIA, V_NRHORDIAM, V_IDTIPOHORARIO, V_NRINTERVALOHORARIO, '''||V_DSJUSTIF_OCORRENCIA||''');'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		COMMIT;'||CHR(10);
				V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
			END IF;	
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'EXCEPTION'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'   	WHEN OTHERS THEN'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    	V_ERR_NUM := SQLCODE;'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    	V_ERR_MSG := SUBSTR(SQLERRM, 1, 100);'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    	dbms_output.put_line(''ERROR: ''||V_ERR_MSG);'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'END;'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'/'||CHR(10);
			OUT_RECORD.DSCOMANDOSQL := V_DSCOMANDOSQL;
			PIPE ROW (OUT_RECORD);
			V_COUNT_SQL := V_COUNT_SQL + 1;
		END LOOP;
		CLOSE C_MARC_PONTO;
	END IF;

	IF P_CTRL_JORNADA = 'N' THEN
		OPEN C_SERV_PREST;
		LOOP
			FETCH C_SERV_PREST INTO V_CDEMPRESA, V_CDFUNC, V_DTPONTO, V_IDPONTO, V_NRORG_SAAS, V_NRVINCULOM_SAAS;
			EXIT WHEN C_SERV_PREST%NOTFOUND;
			
			V_NRORG := NVL(V_NRORG_SAAS, V_NRORG);
			V_NRVINCULOM := NVL(V_NRVINCULOM_SAAS, V_NRVINCULOM);
			V_STDTPONTO := TO_CHAR(V_DTPONTO, 'DD/MM/YYYY');
			
			V_DSCOMANDOSQL := '';
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'DECLARE'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_NRRESUMOSITUFREQ PTO_RESUMOSITUFREQ.NRRESUMOSITUFREQ%TYPE;'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_NRPERIODOAPURACAO PTO_PERIODOAPURACAO.NRPERIODOAPURACAO%TYPE;'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_NRTIPOPERIODOAPURACAO PTO_TIPOPERIODOAPURACAO.NRTIPOPERIODOAPURACAO%TYPE;'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_NRSITUFREQUENCIA PTO_SITUFREQUENCIA.NRSITUFREQUENCIA%TYPE;'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_STNOVOCOD NOVOCODIGO.NRSEQUENCIAL%TYPE;'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_ERR_NUM NUMBER;'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    V_ERR_MSG VARCHAR2(100);'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'BEGIN'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    dbms_output.put_line(''Comando no.: '||TO_CHAR(V_COUNT_SQL)||''');'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		NOVO_CODIGO(''PTO_RESUMOSITUFREQ'', V_STNOVOCOD, 1, '||V_NRORG||');'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		V_NRRESUMOSITUFREQ := TO_NUMBER(V_STNOVOCOD);'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		SELECT MAX(T.NRTIPOPERIODOAPURACAO)'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  INTO V_NRTIPOPERIODOAPURACAO'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  FROM GPE_VINCULOM V, PTO_TIPOPERIODOAPURACAO T'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		 WHERE V.NRORG = '||V_NRORG||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		   AND V.NRVINCULOM = '||V_NRVINCULOM||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		   AND V.NRORG = T.NRORG'||CHR(10);      
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		   AND V.NRTIPOVINCULOM = T.NRTIPOVINCULOM'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		SELECT MAX(P.NRPERIODOAPURACAO)'||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  INTO V_NRPERIODOAPURACAO'||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  FROM PTO_PERIODOAPURACAO P'||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'  	 WHERE P.NRORG = '||V_NRORG||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'  	   AND P.NRTIPOPERIODOAPURACAO = V_NRTIPOPERIODOAPURACAO'||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		   AND P.DTINICIALAPURACAO <= TO_DATE('''||V_STDTPONTO||''', ''DD/MM/YYYY'')'||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		   AND P.DTFINALAPURACAO >= TO_DATE('''||V_STDTPONTO||''', ''DD/MM/YYYY'');'||CHR(10); 			
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		SELECT MAX(NVL(SO.NRSITUFREQUENCIA, SP.NRSITUFREQUENCIA))'||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  INTO V_NRSITUFREQUENCIA'||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		  FROM PTO_SITUFREQUENCIA SO, PTO_SITUFREQUENCIA SP'||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		 WHERE SP.NRORG = '||P_NRORG_PADRAO||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		   AND SP.DSABREVIACAO = ''FALTAS_DIURNAS'''||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		   AND SO.NRORG(+) = '||V_NRORG||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		   AND SO.DSABREVIACAO(+) = ''FALTAS_DIURNAS'''||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		   AND SO.DSABREVIACAO(+) = SP.DSABREVIACAO'||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		INSERT INTO PTO_RESUMOSITUFREQ(NRORG, NRRESUMOSITUFREQ, NRPERIODOAPURACAO, NRVINCULOM,'||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		                               DTAPURACAOSITUFREQ, QTREFAPURSITUFREQ, NRSITUFREQUENCIA, IDCONFIRMADA)'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'			  VALUES ('||V_NRORG||', V_NRRESUMOSITUFREQ, V_NRPERIODOAPURACAO, '||V_NRVINCULOM||','||CHR(10); 
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		             TO_DATE('''||V_STDTPONTO||''', ''DD/MM/YYYY''), 0, V_NRSITUFREQUENCIA, ''S'');'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||''||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'		COMMIT;'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'EXCEPTION'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'   	WHEN OTHERS THEN'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    	V_ERR_NUM := SQLCODE;'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    	V_ERR_MSG := SUBSTR(SQLERRM, 1, 100);'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'    	dbms_output.put_line(''ERROR: ''||V_ERR_MSG);'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'END;'||CHR(10);
			V_DSCOMANDOSQL := V_DSCOMANDOSQL||'/'||CHR(10);
			OUT_RECORD.DSCOMANDOSQL := V_DSCOMANDOSQL;
			PIPE ROW (OUT_RECORD);
			V_COUNT_SQL := V_COUNT_SQL + 1;
		END LOOP;
		CLOSE C_SERV_PREST;
	END IF;
	
   RETURN;
END;
/